@@ -36,6 +36,7 @@ import urllib3
 import time
 import datetime
 import hashlib
+import hmac
 
 sys.path.append(os.path.dirname(os.path.realpath(__file__)))
 from version import VERSION
@@ -104,6 +105,19 @@ class Client:
             'User-Agent': 'Algolia Search for python'
         }
 
+
+    def multipleQueries(self, queries, indexNameKey = "indexName"):
+        """
+        This method allows to query multiple indexes with one API call
+        """
+        requests = []
+        for query in queries:
+            indexName = query[indexNameKey]
+            del query[indexNameKey]
+            requests.append({"indexName": indexName, "params": urlencode(query)})
+        body = {"requests": requests}
+        return AlgoliaUtils_request(self.headers, self.hosts, "POST", "/1/indexes/*/queries", body)
+
     def listIndexes(self):
         """
         List all existing indexes
@@ -142,14 +156,14 @@ class Client:
         request = {"operation": "copy", "destination": dstIndexName}
         return AlgoliaUtils_request(self.headers, self.hosts, "POST", "/1/indexes/%s/operation" % (quote(srcIndexName.encode('utf8'), safe='')), request)
 
-    def getLogs(self, offset = 0, length = 10):
+    def getLogs(self, offset = 0, length = 10, onlyErrors = False):
         """
         Return last logs entries.
 
         @param offset Specify the first entry to retrieve (0-based, 0 is the most recent log entry).
         @param length Specify the maximum number of entries to retrieve starting at offset. Maximum allowed value: 1000.
         """
-        return AlgoliaUtils_request(self.headers, self.hosts, "GET", "/1/logs?offset=%d&length=%d" % (offset, length))
+        return AlgoliaUtils_request(self.headers, self.hosts, "GET", "/1/logs?offset=%d&length=%d&onlyErrors=%s" % (offset, length, onlyErrors))
 
     def initIndex(self, indexName):
         """
@@ -210,7 +224,7 @@ class Client:
         """
         if type(tag_filters) is list:
             tag_filters = ','.join(map(lambda t: ''.join(['(', ','.join(t), ')']) if type(t) is list else str(t), tag_filters))
-        return hashlib.sha256(''.join([private_api_key, str(tag_filters), str(user_token or '')]).encode('utf-8')).hexdigest()
+        return hmac.new(str.encode(private_api_key), str.encode(''.join([str(tag_filters), str(user_token or '')])),  hashlib.sha256).hexdigest()
 
 class Index:
     """
@@ -571,7 +585,10 @@ def AlgoliaUtils_request(headers, hosts, method, request, body = None):
 class JSONEncoderWithDatetimeAndDefaultToString(json.JSONEncoder):
     def default(self, obj):
         if isinstance(obj, datetime.datetime):
-            return int(time.mktime(obj.timetuple()))
+            try:
+                return int(time.mktime(obj.timetuple()))
+            except:
+                return 0
         try:
             return json.JSONEncoder.default(self, obj)
         except:
